MutableRequest

Struct MutableRequest 

pub struct MutableRequest<T>
where T: Body<Data = Bytes> + Send + 'static, T::Error: Into<Box<dyn Error + Send + Sync>>,
{ pub parts: Parts, pub body: T, }
Represents an HTTP request (from hyper) with helpers for mutating it.

Fields

parts: Partsbody: T

Implementations

Source

impl<T> MutableRequest<T>
where T: Body<Data = Bytes> + Send + 'static, T::Error: Into<Box<dyn Error + Send + Sync>>,

pub fn from_request(request: Request<T>) -> Self

pub fn into_request(self) -> Request<T>

pub fn into_request_with_simple_body(self) -> Request<SimpleBody>

pub fn set_upstream_address(&mut self, address: SocketAddr)

Rewrite the request so that it points to the given upstream address.

pub fn add_header(&mut self, key: &str, value: &str)

Add a header to the request.

If the header is invalid, it will be ignored and logged.

pub fn headers_mut(&mut self) -> &mut HeaderMap